BarcodeImageParams class

Optional barcode image parameters.

Constructors

BarcodeImageParams([BarcodeImageFormat? imageFormat, CodeLocation? textLocation, String? foregroundColor, String? backgroundColor, GraphicsUnit? units, double? resolution, double? imageHeight, double? imageWidth, int? rotationAngle])
Constructor
BarcodeImageParams.fromJson(Map<String, dynamic> json)
Creates a BarcodeImageParams instance from a JSON representation.

Properties

backgroundColor String?
Background color of the barcode image. Value: Color name from https://reference.aspose.com/drawing/net/system.drawing/color/ or ARGB value starting with #. For example: AliceBlue or #FF000000. Default value: White.
getter/setter pair
foregroundColor String?
Specify the display color for bars and content. Value: Color name from https://reference.aspose.com/drawing/net/system.drawing/color/ or ARGB value starting with #. For example: AliceBlue or #FF000000. Default value: Black.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
imageFormat BarcodeImageFormat?
Barcode output image format. Default value: png.
getter/setter pair
imageHeight double?
Height of the barcode image in the specified units. Default units: pixels. Decimal separator is a dot.
getter/setter pair
imageWidth double?
Width of the barcode image in the specified units. Default units: pixels. Decimal separator is a dot.
getter/setter pair
resolution double?
Resolution of the barcode image. One value for both dimensions. Default value: 96 dpi. Decimal separator is a dot.
getter/setter pair
rotationAngle int?
Barcode image rotation angle, measured in degrees. For example, RotationAngle = 0 or RotationAngle = 360 means no rotation. If RotationAngle is not equal to 90, 180, 270, or 0, it may increase the difficulty for the scanner to read the image. Default value: 0.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textLocation CodeLocation?
Specify the displayed text location. Set to CodeLocation.None to hide CodeText. Default value depends on BarcodeType: CodeLocation.Below for 1D barcodes and CodeLocation.None for 2D barcodes.
getter/setter pair
units GraphicsUnit?
Common units for all measurements. Default units: pixels.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a JSON representation of BarcodeImageParams.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

listFromJson(List json) List<BarcodeImageParams>
Converts a list of JSON objects to a list of BarcodeImageParams instances.