imageHeight property
Height of the barcode image in the specified units. Default units: pixels. Decimal separator is a dot.
Implementation
double? imageHeight;
Height of the barcode image in the specified units. Default units: pixels. Decimal separator is a dot.
double? imageHeight;