imageWidth property
Width of the barcode image in the specified units. Default units: pixels. Decimal separator is a dot.
Implementation
double? imageWidth;
Width of the barcode image in the specified units. Default units: pixels. Decimal separator is a dot.
double? imageWidth;