Code128Params class

Optional Code128 barcode generation parameters.

Constructors

Code128Params([Code128EncodeMode? code128EncodeMode])
Constructor
Code128Params.fromJson(Map<String, dynamic> json)
Creates a Code128Params instance from a JSON representation.

Properties

code128EncodeMode Code128EncodeMode?
Code128 barcode encode mode. Controls which Code 128 subset (A, B, C, or mix) is used.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a JSON representation of Code128Params.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

listFromJson(List json) List<Code128Params>
Converts a list of JSON objects to a list of Code128Params instances.