GenerateApi class

GenerateApi

Constructors

GenerateApi(ApiClient _apiClient)
Constructor

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generate(EncodeBarcodeType barcodeType, String data, {EncodeDataType? dataType, BarcodeImageParams? barcodeImageParams, QrParams? qrParams, Code128Params? code128Params, Pdf417Params? pdf417Params}) Future<Uint8List>
Generate a barcode using a GET request with parameters in the route and query string.
generateBody(GenerateParams generateParams) Future<Uint8List>
Generate a barcode using a POST request with parameters in the request body in JSON or XML format.
generateMultipart(EncodeBarcodeType barcodeType, String data, {EncodeDataType? dataType, BarcodeImageParams? barcodeImageParams, QrParams? qrParams, Code128Params? code128Params, Pdf417Params? pdf417Params}) Future<Uint8List>
Generate a barcode using a POST request with parameters in a multipart form.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited