GenerateParams class

Barcode generation parameters.

Constructors

GenerateParams(EncodeBarcodeType barcodeType, EncodeData encodeData, [BarcodeImageParams? barcodeImageParams, QrParams? qrParams, Code128Params? code128Params, Pdf417Params? pdf417Params])
Constructor
GenerateParams.fromJson(Map<String, dynamic> json)
Creates a GenerateParams instance from a JSON representation.

Properties

barcodeImageParams BarcodeImageParams?
Optional barcode image parameters.
getter/setter pair
barcodeType EncodeBarcodeType
Barcode type.
getter/setter pair
code128Params Code128Params?
Optional Code128 barcode generation parameters.
getter/setter pair
encodeData EncodeData
Data to encode into a barcode.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
pdf417Params Pdf417Params?
Optional PDF417 barcode generation parameters.
getter/setter pair
qrParams QrParams?
Optional QR barcode generation parameters.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a JSON representation of GenerateParams.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

listFromJson(List json) List<GenerateParams>
Converts a list of JSON objects to a list of GenerateParams instances.