GraphicsUnit class

Subset of https://reference.aspose.com/drawing/net/system.drawing/graphicsunit/ GraphicsUnit: Pixel, Point, Inch, Millimeter

Constructors

GraphicsUnit.fromJson(dynamic data)
Creates a GraphicsUnit instance from a JSON representation.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String?
Returns a JSON representation of GraphicsUnit.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

listFromJson(List json) List<GraphicsUnit>
Converts a list of JSON objects to a list of GraphicsUnit instances.