Pdf417EncodeMode class

PDF417 barcode encode mode. Mirrors https://reference.aspose.com/barcode/net/aspose.barcode.generation/pdf417encodemode/ Pdf417EncodeMode: Auto, Binary, ECI, Extended

Constructors

Pdf417EncodeMode.fromJson(dynamic data)
Creates a Pdf417EncodeMode instance from a JSON representation.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String?
Returns a JSON representation of Pdf417EncodeMode.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

listFromJson(List json) List<Pdf417EncodeMode>
Converts a list of JSON objects to a list of Pdf417EncodeMode instances.