Pdf417ErrorLevel class

PDF417 barcode error correction level. Mirrors https://reference.aspose.com/barcode/net/aspose.barcode.generation/pdf417errorlevel/ Pdf417ErrorLevel: Level0, Level1, Level2, Level3, Level4, Level5, Level6, Level7, Level8

Constructors

Pdf417ErrorLevel.fromJson(dynamic data)
Creates a Pdf417ErrorLevel instance from a JSON representation.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String?
Returns a JSON representation of Pdf417ErrorLevel.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

Level0 Pdf417ErrorLevel
PDF417 barcode error correction level. Mirrors https://reference.aspose.com/barcode/net/aspose.barcode.generation/pdf417errorlevel/
final
Level1 Pdf417ErrorLevel
PDF417 barcode error correction level. Mirrors https://reference.aspose.com/barcode/net/aspose.barcode.generation/pdf417errorlevel/
final
Level2 Pdf417ErrorLevel
PDF417 barcode error correction level. Mirrors https://reference.aspose.com/barcode/net/aspose.barcode.generation/pdf417errorlevel/
final
Level3 Pdf417ErrorLevel
PDF417 barcode error correction level. Mirrors https://reference.aspose.com/barcode/net/aspose.barcode.generation/pdf417errorlevel/
final
Level4 Pdf417ErrorLevel
PDF417 barcode error correction level. Mirrors https://reference.aspose.com/barcode/net/aspose.barcode.generation/pdf417errorlevel/
final
Level5 Pdf417ErrorLevel
PDF417 barcode error correction level. Mirrors https://reference.aspose.com/barcode/net/aspose.barcode.generation/pdf417errorlevel/
final
Level6 Pdf417ErrorLevel
PDF417 barcode error correction level. Mirrors https://reference.aspose.com/barcode/net/aspose.barcode.generation/pdf417errorlevel/
final
Level7 Pdf417ErrorLevel
PDF417 barcode error correction level. Mirrors https://reference.aspose.com/barcode/net/aspose.barcode.generation/pdf417errorlevel/
final
Level8 Pdf417ErrorLevel
PDF417 barcode error correction level. Mirrors https://reference.aspose.com/barcode/net/aspose.barcode.generation/pdf417errorlevel/
final

Static Methods

listFromJson(List json) List<Pdf417ErrorLevel>
Converts a list of JSON objects to a list of Pdf417ErrorLevel instances.