Pdf417Params class

Optional PDF417 barcode generation parameters. Applies to Pdf417, MacroPdf417, MicroPdf417, and GS1MicroPdf417 barcode types.

Constructors

Pdf417Params([Pdf417EncodeMode? pdf417EncodeMode, Pdf417ErrorLevel? pdf417ErrorLevel, bool? pdf417Truncate, int? pdf417Columns, int? pdf417Rows, double? pdf417AspectRatio, ECIEncodings? pdf417ECIEncoding, bool? pdf417IsReaderInitialization, MacroCharacter? pdf417MacroCharacters, bool? pdf417IsLinked, bool? pdf417IsCode128Emulation])
Constructor
Pdf417Params.fromJson(Map<String, dynamic> json)
Creates a Pdf417Params instance from a JSON representation.

Properties

hashCode int
The hash code for this object.
no setterinherited
pdf417AspectRatio double?
PDF417 barcode aspect ratio (height/width of the barcode module). Values are defined by the standard: 2 to 5 for MicroPdf417; 3 to 5 for Pdf417 and MacroPdf417.
getter/setter pair
pdf417Columns int?
Number of columns in the PDF417 barcode. Values between 1 and 30. 0 for auto.
getter/setter pair
pdf417ECIEncoding ECIEncodings?
ECI encoding for PDF417 barcode data.
getter/setter pair
pdf417EncodeMode Pdf417EncodeMode?
PDF417 barcode encode mode.
getter/setter pair
pdf417ErrorLevel Pdf417ErrorLevel?
PDF417 barcode error correction level.
getter/setter pair
pdf417IsCode128Emulation bool?
Whether to use Code128 emulation for MicroPdf417.
getter/setter pair
pdf417IsLinked bool?
Whether to use linked mode (for MicroPdf417).
getter/setter pair
pdf417IsReaderInitialization bool?
Whether the barcode is used for reader initialization (programming).
getter/setter pair
pdf417MacroCharacters MacroCharacter?
Macro character to prepend (structured append).
getter/setter pair
pdf417Rows int?
Number of rows in the PDF417 barcode. Values between 3 and 90. 0 for automatic.
getter/setter pair
pdf417Truncate bool?
Whether to use truncated PDF417 format (removes right-side stop pattern).
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a JSON representation of Pdf417Params.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

listFromJson(List json) List<Pdf417Params>
Converts a list of JSON objects to a list of Pdf417Params instances.