pdf417IsReaderInitialization property
Whether the barcode is used for reader initialization (programming).
Implementation
bool? pdf417IsReaderInitialization;
Whether the barcode is used for reader initialization (programming).
bool? pdf417IsReaderInitialization;