toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  return 'Pdf417Params[pdf417EncodeMode=$pdf417EncodeMode, pdf417ErrorLevel=$pdf417ErrorLevel, pdf417Truncate=$pdf417Truncate, pdf417Columns=$pdf417Columns, pdf417Rows=$pdf417Rows, pdf417AspectRatio=$pdf417AspectRatio, pdf417ECIEncoding=$pdf417ECIEncoding, pdf417IsReaderInitialization=$pdf417IsReaderInitialization, pdf417MacroCharacters=$pdf417MacroCharacters, pdf417IsLinked=$pdf417IsLinked, pdf417IsCode128Emulation=$pdf417IsCode128Emulation, ]';
}