RecognizeApi class

RecognizeApi

Constructors

RecognizeApi(ApiClient _apiClient)
Constructor

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recognize(DecodeBarcodeType barcodeType, String fileUrl, {RecognitionMode? recognitionMode, RecognitionImageKind? recognitionImageKind}) Future<BarcodeResponseList>
Recognize a barcode from a file on an Internet server using a GET request with a query string parameter. For recognizing files from your hard drive, use `recognize-body` or `recognize-multipart` endpoints instead.
recognizeBase64(RecognizeBase64Request recognizeBase64Request) Future<BarcodeResponseList>
Recognize a barcode from a file in the request body using a POST request with JSON or XML body parameters.
recognizeMultipart(DecodeBarcodeType barcodeType, Uint8List fileBytes, {RecognitionMode? recognitionMode, RecognitionImageKind? recognitionImageKind}) Future<BarcodeResponseList>
Recognize a barcode from a file in the request body using a POST request with multipart form parameters.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited