ScanApi class

ScanApi

Constructors

ScanApi(ApiClient _apiClient)
Constructor

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scan(String fileUrl) Future<BarcodeResponseList>
Scan a barcode from a file on an Internet server using a GET request with a query string parameter. For scanning files from your hard drive, use `scan-body` or `scan-multipart` endpoints instead.
scanBase64(ScanBase64Request scanBase64Request) Future<BarcodeResponseList>
Scan a barcode from a file in the request body using a POST request with a JSON or XML body parameter.
scanMultipart(Uint8List fileBytes) Future<BarcodeResponseList>
Scan a barcode from a file in the request body using a POST request with a multipart form parameter.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited