MicroQRVersion class
MicroQR barcode version. Mirrors https://reference.aspose.com/barcode/net/aspose.barcode.generation/microqrversion/
MicroQRVersion: Auto, M1, M2, M3, M4
Constructors
- MicroQRVersion.fromJson(dynamic data)
- Creates a MicroQRVersion instance from a JSON representation.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String? - Returns a JSON representation of MicroQRVersion.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- Auto → MicroQRVersion
-
MicroQR barcode version. Mirrors https://reference.aspose.com/barcode/net/aspose.barcode.generation/microqrversion/
final
- M1 → MicroQRVersion
-
MicroQR barcode version. Mirrors https://reference.aspose.com/barcode/net/aspose.barcode.generation/microqrversion/
final
- M2 → MicroQRVersion
-
MicroQR barcode version. Mirrors https://reference.aspose.com/barcode/net/aspose.barcode.generation/microqrversion/
final
- M3 → MicroQRVersion
-
MicroQR barcode version. Mirrors https://reference.aspose.com/barcode/net/aspose.barcode.generation/microqrversion/
final
- M4 → MicroQRVersion
-
MicroQR barcode version. Mirrors https://reference.aspose.com/barcode/net/aspose.barcode.generation/microqrversion/
final
Static Methods
-
listFromJson(
List json) → List< MicroQRVersion> - Converts a list of JSON objects to a list of MicroQRVersion instances.