QrParams class
Optional QR barcode generation parameters. Applies to QR, GS1QR, MicroQR, and RectMicroQR barcode types.
Constructors
- QrParams([QREncodeMode? qrEncodeMode, QRErrorLevel? qrErrorLevel, QRVersion? qrVersion, ECIEncodings? qrECIEncoding, double? qrAspectRatio, MicroQRVersion? microQRVersion, RectMicroQRVersion? rectMicroQrVersion])
- Constructor
-
QrParams.fromJson(Map<
String, dynamic> json) - Creates a QrParams instance from a JSON representation.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- microQRVersion ↔ MicroQRVersion?
-
MicroQR barcode version. Used when BarcodeType is MicroQR.
getter/setter pair
- qrAspectRatio ↔ double?
-
QR barcode aspect ratio. Values: 0 to 1.
getter/setter pair
- qrECIEncoding ↔ ECIEncodings?
-
ECI encoding for QR barcode data.
getter/setter pair
- qrEncodeMode ↔ QREncodeMode?
-
QR barcode encode mode.
getter/setter pair
- qrErrorLevel ↔ QRErrorLevel?
-
QR barcode error correction level.
getter/setter pair
- qrVersion ↔ QRVersion?
-
QR barcode version. Automatically selects the smallest version that fits the data.
getter/setter pair
- rectMicroQrVersion ↔ RectMicroQRVersion?
-
RectMicroQR barcode version. Used when BarcodeType is RectMicroQR.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Returns a JSON representation of QrParams.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
listFromJson(
List json) → List< QrParams> - Converts a list of JSON objects to a list of QrParams instances.